﻿// ============================================================================
// Movo Network API Sample
//
// <ApiSample1.cs>
//
// Copyright (c) 2008 Servoland corporation.
// All rights reserved.
//
// 目的：
//		コマンド通信を行う端末を作成します。
//
// Version情報：					  -- 追加, 修正項目 --
//		Version 1.0		2008.08.11	: First construction.
//
// ============================================================================
using System;
using MovoEtherVB.Servoland;


namespace CS_ApiSample1
{
    class CS_ApiSample1
    {
        private static MovoAPI api;
        private static int iDevSel;

        // =====================================================================
        // エントリーポイント
        // =====================================================================
        static void Main(string[] args)
        {
            int iRc;
            String line;

            iRc = Initialize();
            if (iRc != 0)
            {
                // 初期化失敗
                Console.WriteLine("Initialization failed (Hit Enter to exit)");
                line = Console.ReadLine();
                return;
            }

            Terminal();

        }

        // =====================================================================
        // 初期化
        // =====================================================================
        static int Initialize()
        {
            String strBuf = ""; // 文字列バッファ
            int i;              // Counter
            int iRc;            // Return code
            int IFNum;          // Ethernet I/Fの数
            int IFSel;          // 使用するEthetnet I/F
            String strIP = "";  // IPアドレス(文字列)
            int pIP=0;          // IPアドレス(整数)
            String strSN = "";  // サブネットマスク(文字列)
            int pSN=0;          // サブネットマスク(整数)

            api = new MovoAPI(); // MovoAPIクラスのインスタンス生成

            iDevSel = 0; // 通信デバイス=Ethernet

            // APIのバージョン取得
            api.GetLibVersion(ref strBuf);
            strBuf = "Network API version " + strBuf + "\n";

            Console.WriteLine(strBuf);

            // I/Fを設定(Ethernet使用時)
            if (iDevSel == 0)
            {
                // 使用可能なEthernet I/Fを検索
                IFNum = api.SearchInterface(iDevSel);
                if (IFNum < 0)
                {
                    Console.WriteLine("No ethernet I/F found");
                    return -1;
                }

                Console.WriteLine(IFNum.ToString() + " ethernet I/F found");

                // 各I/Fの情報を表示
                for (i = 0; i < IFNum; i++)
                {
                    api.GetHostIP(iDevSel, i, ref strIP, ref pIP);
                    api.GetHostSN(iDevSel, i, ref strSN, ref pSN);
                    Console.WriteLine(i.ToString() + " : " + String.Format("{0,-16}", strIP) + "(" + String.Format("{0,-16}", strSN) + ")");
                }

                if (IFNum == 1)
                {
                    // I/Fが１つのときは自動選択
                    IFSel = 0;
                }
                else
                {
                    // I/Fが２つ以上のときはユーザが選択
                    do
                    {
                        Console.Write("Select I/F to use [0-" + (IFNum - 1).ToString() + "]> ");
                        strBuf = Console.ReadLine();
                        try
                        {
                            IFSel = Convert.ToInt32(strBuf);
                        }
                        catch
                        {
                            IFSel = -1;
                        }
                    } while (IFSel < 0 || IFSel >= IFNum);

                }
                Console.WriteLine("I/F " + IFSel.ToString() + " selected\n");

                // Ethernet I/Fを設定
                api.SetInterface(iDevSel, IFSel);
            }

            // 接続されたドライバの検索
            iRc = api.SearchDevice(iDevSel, ref strBuf);
            if (iRc <= 0)
            {
                Console.WriteLine("No driver found");
                return -1;
            }

            // 接続可能なすべてのドライバに接続
            iRc = api.ConnectAll(iDevSel, ref strBuf);
            if (iRc > 0)
            {
                Console.WriteLine("Driver " + strBuf + " connected");
            }
            else
            {
                Console.WriteLine("No driver found");
                return -1;
            }
            return 0;
        }

        // =====================================================================
        // コマンド通信端末
        // =====================================================================
        static void Terminal()
        {
            Char ID;
            String strBuf;
            int iRc;

            // コマンド送信対象を全軸に設定
            ID = '*';
            api.SetComID(iDevSel, ID);

            Console.WriteLine("Type command and press enter-key, or type \"quit\" to exit program");

            for(;;){
                // コマンド入力
                Console.Write("  " + ID.ToString() + " > ");
                strBuf = Console.ReadLine();

                // 終了確認
                if(strBuf== "quit")
                    break;
                
                // コマンド送信
                iRc = api.SendCom(iDevSel, ref strBuf);

                // 送信ステータスチェック
                if(iRc == MovoAPI.MOVO_HASDATA){
                    // 返信データの獲得
                    api.RecvCom(iDevSel, ref strBuf);
                    Console.WriteLine("  " + ID.ToString() + " > " + strBuf);

                }else if(iRc ==MovoAPI.MOVO_FAILURE){
                    // エラー情報の獲得
                    api.GetErrorText(iDevSel, ref strBuf);
                    Console.WriteLine("  Error: " + strBuf);
                }

                // 現在のコマンド送信対象を確認
                api.GetComID(iDevSel, ref ID);
            }

        }

    }
}
