﻿' ============================================================================
' Movo Network API Sample
'
' <ApiSample1.vb>
'
' Copyright (c) 2008 Servoland corporation.
' All rights reserved.
'
' 目的：
'		コマンド通信を行う端末を作成します。
'
' Version情報：					    -- 追加, 修正項目 --
'		Version 1.0		2008.08.11	: First construction.
'
' ============================================================================
Imports MovoEtherVB.Servoland

Module VB_ApiSample1
    Dim iDevSel As Integer
    Dim api As MovoAPI

    ' =========================================================================
    ' エントリーポイント
    ' =========================================================================
    Sub Main()
        Dim iRc As Integer
        Dim line As String

        iRc = Initialize()
        If iRc <> 0 Then
            ' 初期化失敗
            Console.WriteLine("Initialization failed (Hit Enter to exit)")
            line = Console.ReadLine()
            Return
        End If

        Terminal()

    End Sub

    ' =========================================================================
    ' 初期化
    ' =========================================================================
    Function Initialize() As Integer
        Dim Str As String = ""  ' 文字列バッファ
        Dim i As Integer        ' Counter
        Dim iRc As Integer      ' Return code
        Dim IFNum As Integer    ' Ethernet I/Fの数
        Dim IFSel As Integer    ' 使用するEthetnet I/F
        Dim strIP As String = ""    ' IPアドレス(文字列)
        Dim pIP As Integer          ' IPアドレス(整数)
        Dim strSN As String = ""    ' サブネットマスク(文字列)
        Dim pSN As Integer          ' サブネットマスク(整数)

        api = New MovoAPI ' MovoAPIクラスのインスタンス生成

        iDevSel = 0 ' 通信デバイス=Ethernet

        ' APIのバージョン取得
        api.GetLibVersion(Str)
        Str = "Network API version " + Str + ControlChars.NewLine

        Console.WriteLine(Str)

        ' I/Fを設定(Ethernet使用時)
        If iDevSel = 0 Then
            ' 使用可能なEthernet I/Fを検索
            IFNum = api.SearchInterface(iDevSel)
            If IFNum < 0 Then
                Console.WriteLine("No ethernet I/F found")
                Return -1
            End If
            Console.WriteLine(IFNum.ToString + " ethernet I/F found")

            ' 各I/Fの情報を表示
            For i = 0 To IFNum - 1
                api.GetHostIP(iDevSel, i, strIP, pIP)
                api.GetHostSN(iDevSel, i, strSN, pSN)
                Console.WriteLine(i.ToString + " : " + String.Format("{0,-16}", strIP) + "(" + String.Format("{0,-16}", strSN) + ")")
            Next

            If IFNum = 1 Then
                ' I/Fが１つのときは自動選択
                IFSel = 0
            Else
                ' I/Fが２つ以上のときはユーザが選択
                Do
                    Console.Write("Select I/F to use [0-" + (IFNum - 1).ToString + "]> ")
                    Str = Console.ReadLine()
                    Try
                        IFSel = Convert.ToInt32(Str)
                    Catch
                        IFSel = -1
                    End Try
                Loop While IFSel < 0 Or IFSel >= IFNum

            End If
            Console.WriteLine("I/F " + IFSel.ToString + " selected" + ControlChars.NewLine)

            ' Ethernet I/Fを設定
            api.SetInterface(iDevSel, IFSel)

        End If

        ' 接続されたドライバの検索
        iRc = api.SearchDevice(iDevSel, Str)
        If iRc <= 0 Then
            Console.WriteLine("No driver found")
            Return -1
        End If

        ' 接続可能なすべてのドライバに接続
        iRc = api.ConnectAll(iDevSel, Str)
        If iRc > 0 Then
            Console.WriteLine("Driver " + Str + " connected")
        Else
            Console.WriteLine("No driver found")
            Return -1
        End If

        Return 0

    End Function

    ' =========================================================================
    ' コマンド通信端末
    ' =========================================================================
    Sub Terminal()
        Dim ID As Char
        Dim strBuf As String
        Dim iRc As Integer

        ' コマンド送信対象を全軸に設定
        ID = "*"
        api.SetComID(iDevSel, ID)

        Console.WriteLine("Type command and press enter-key, or type " + ControlChars.Quote + "quit" + ControlChars.Quote + " to exit program")

        Do
            ' コマンド入力
            Console.Write("  " + ID.ToString + " > ")
            strBuf = Console.ReadLine

            ' 終了確認
            If strBuf = "quit" Then
                Exit Do
            End If

            ' コマンド送信
            iRc = api.SendCom(iDevSel, strBuf)

            ' 送信ステータスチェック
            If iRc = MovoAPI.MOVO_HASDATA Then
                ' 返信データの獲得
                api.RecvCom(iDevSel, strBuf)
                Console.WriteLine("  " + ID.ToString + " > " + strBuf)

            ElseIf iRc = MovoAPI.MOVO_FAILURE Then
                ' エラー情報の獲得
                api.GetErrorText(iDevSel, strBuf)
                Console.WriteLine("  Error: " + strBuf)
            End If

            ' 現在のコマンド送信対象を確認
            api.GetComID(iDevSel, ID)
        Loop

    End Sub

End Module
